// Arup Guha
// 4/12/2013
// Solution to COP 3503 Program 5B: Cheer

import java.util.*;

public class cheer {

	final public static boolean DEBUG = false;

	public static void main(String[] args) {

		Scanner stdin = new Scanner(System.in);
		int numCases = stdin.nextInt();

		// Go through each case.
		for (int loop=0; loop<numCases; loop++) {

			int n = stdin.nextInt();
			cheerleader[] squad = new cheerleader[n];

			// Read in all cheerleaders.
			for (int i=0; i<n; i++) {
				int weight = stdin.nextInt();
				int canCarry = stdin.nextInt();
				squad[i] = new cheerleader(weight, canCarry);
			}

			// Put these in order by carrying capacity.
			// This is a greedy step to set up our DP.
			Arrays.sort(squad);

			System.out.println(solve(squad));
		}
	}

	// Pre-condition: squad is sorted in ascending order by extra carrying capacity.
	public static int solve(cheerleader[] squad) {

		// Set up DP.
		int n = squad.length;
		towerPerson[] dp = new towerPerson[n];
		for (int i=0; i<dp.length; i++)
			dp[i] = null;


		// Skip over cheerleaders that can't hold themselves up!
		// Note that the problem specification doesn't preclude this.
		int i=0;
		while (i < n && squad[i].extraCapacity < 0) i++;

		// No one can even hold themselves up!
		if (i == n) return 0;

		// This is our first valid starting point.
		int startI = i;

		// Main DP loop: we are attempting to form the best tower with
		// person i at the bottom.
		for (i=startI; i<n; i++) {

			// At the very least this can be our tower, a tower of 1.
			towerPerson best = new towerPerson(squad[i], i);

			// Try to build off old towers.
			for (int j=startI; j<i; j++) {

				// We can add person i to this tower, so try it.
				if (dp[j].canAddToBottom(squad[i])) {

					towerPerson temp = dp[j].addToBottom(squad[i], i);
					if (temp.compareTo(best) > 0)
						best = temp;
				}
			}

			// We have found the best person here.
			dp[i] = best;
		}


		// Optional: you can print out an actual best tower.
		// This one will be with person n-1 at the bottom.
		if (DEBUG) {

			ArrayList<Integer> myTower = new ArrayList<Integer>();

			// Build tower from bottom to top.
			int cur = n-1;
			while (cur != -1) {
				myTower.add(cur);
				cur = dp[cur].previousPerson;
			}

			// Flip from bottom to top.
			Collections.reverse(myTower);

			// Print out each person in the tower.
			for (i=0; i<myTower.size(); i++) {
				System.out.println(myTower.get(i)+". "+squad[myTower.get(i)]);
			}
		}

		// This is the desired answer.
		return dp[n-1].numPeople;
	}
}



class cheerleader implements Comparable<cheerleader> {

	public int weight;
	public int extraCapacity;

	public cheerleader(int w, int cap) {
		weight = w;
		extraCapacity = cap - w;
	}

	public int compareTo(cheerleader other) {
		return this.extraCapacity - other.extraCapacity;
	}

	public String toString() {
		return weight+" "+(weight+extraCapacity);
	}

}

// Really just a data structure to implement the DP. I've added some extra information here
// so we can build the actual tower if we choose to do so.
class towerPerson implements Comparable<towerPerson> {

	public int numPeople;
	public int totalWeight;
	public int ID;
	public int previousPerson;

	// This is the starting of a new tower, from the top.
	public towerPerson(cheerleader c, int newID) {
		numPeople = 1;
		totalWeight = c.weight;
		previousPerson = -1;
		ID = newID;
	}

	public towerPerson(int people, int weight, int newID, int previous) {
		numPeople = people;
		totalWeight = weight;
		ID = newID;
		previousPerson = previous;
	}

	// We can only add c to the bottom if she can carry the whole
	// current tower, in addition to herself.
	public boolean canAddToBottom(cheerleader c) {
		return totalWeight <= c.extraCapacity;
	}

	// Returns a new tower with c added to the bottom of this tower. This addition
	// must be valid and bottomIndex is the index of the cheerleader on the bottom
	// of this tower.
	public towerPerson addToBottom(cheerleader c, int newID) {
		return new towerPerson(numPeople+1, totalWeight+c.weight, newID, ID);
	}

	public int compareTo(towerPerson other) {

		// It's better to have more people.
		if (this.numPeople != other.numPeople)
			return this.numPeople - other.numPeople;

		// It's better for them to weigh less.
		return other.totalWeight - this.totalWeight;
	}
}